#ifndef KCDDBI18N_H
#define KCDDBI18N_H

#define TRANSLATION_DOMAIN "libkcddb"
#include <KLocalizedString>

#endif // KCDDBI18N_H
